@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.5.1.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -31,8 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
 
 #ifndef YY_YY_SRC_PARSER_PARSER_HPP_INCLUDED
 # define YY_YY_SRC_PARSER_PARSER_HPP_INCLUDED
@@ -44,32 +45,41 @@
 extern int yydebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    IN = 258,
-    SQRT = 259,
-    FMA = 260,
-    NE = 261,
-    LE = 262,
-    GE = 263,
-    RDIV = 264,
-    FIX = 265,
-    FLT = 266,
-    NUMBER = 267,
-    IDENT = 268,
-    VARID = 269,
-    FUNID = 270,
-    IMPL = 271,
-    OR = 272,
-    AND = 273,
-    NOT = 274,
-    NEG = 275
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    IN = 258,                      /* IN  */
+    SQRT = 259,                    /* SQRT  */
+    FMA = 260,                     /* FMA  */
+    NE = 261,                      /* NE  */
+    LE = 262,                      /* LE  */
+    GE = 263,                      /* GE  */
+    RDIV = 264,                    /* RDIV  */
+    FIX = 265,                     /* FIX  */
+    FLT = 266,                     /* FLT  */
+    NUMBER = 267,                  /* NUMBER  */
+    IDENT = 268,                   /* IDENT  */
+    VARID = 269,                   /* VARID  */
+    FUNID = 270,                   /* FUNID  */
+    IMPL = 271,                    /* IMPL  */
+    OR = 272,                      /* OR  */
+    AND = 273,                     /* AND  */
+    NOT = 274,                     /* NOT  */
+    NEG = 275                      /* NEG  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEMPTY -2
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define IN 258
 #define SQRT 259
 #define FMA 260
@@ -108,7 +118,7 @@ union YYSTYPE
   hint_cond		*precond;
   hint_cond_vect	*preconds;
 
-#line 112 "src/parser/parser.hpp"
+#line 122 "src/parser/parser.hpp"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -132,6 +142,8 @@ struct YYLTYPE
 
 
 
+
 int yyparse (void);
 
+
 #endif /* !YY_YY_SRC_PARSER_PARSER_HPP_INCLUDED  */
