@@ -41,7 +41,7 @@ REGISTER_SCHEME_BEGIN(absolute_error);
     : proof_scheme(predicated_real(r, PRED_BND), preal_vect(), ""), function(f) {}
 REGISTER_SCHEME_END(absolute_error);
 
-void absolute_error_scheme::compute(property const hyps[], property &res, std::string &name) const
+void absolute_error_scheme::compute(property const [], property &res, std::string &name) const
 {
   res.bnd() = function->absolute_error(name);
 }
@@ -141,7 +141,7 @@ REGISTER_SCHEME_BEGIN(relative_error);
     : proof_scheme(r, preal_vect(), ""), function(f) {}
 REGISTER_SCHEME_END_PREDICATE(relative_error);
 
-void relative_error_scheme::compute(property const hyps[], property &res, std::string &name) const
+void relative_error_scheme::compute(property const [], property &res, std::string &name) const
 {
   res.bnd() = function->relative_error(name);
 }
@@ -273,7 +273,7 @@ REGISTER_SCHEME_BEGIN(sub_of_eql);
     : proof_scheme(r, preal_vect(1, n), "sub_of_eql", UPD_TRIV) {}
 REGISTER_SCHEME_END_PATTERN(sub_of_eql, predicated_real(pattern(0) - pattern(1), PRED_BND));
 
-void sub_of_eql_scheme::compute(property const hyps[], property &res, std::string &) const
+void sub_of_eql_scheme::compute(property const [], property &res, std::string &) const
 {
   res.bnd() = zero();
 }
@@ -311,7 +311,7 @@ REGISTER_SCHEME_BEGIN(rel_refl);
     : proof_scheme(r, preal_vect(), "rel_refl", UPD_TRIV) {}
 REGISTER_SCHEME_END_PATTERN(rel_refl, predicated_real(pattern(0), pattern(0), PRED_REL));
 
-void rel_refl_scheme::compute(property const hyps[], property &res, std::string &name) const
+void rel_refl_scheme::compute(property const [], property &res, std::string &) const
 {
   res.bnd() = zero();
 }
@@ -329,7 +329,7 @@ REGISTER_SCHEME_BEGIN(eql_trans);
   static proof_scheme *factory2(predicated_real const &, ast_real_vect const &);
 REGISTER_SCHEME_END_PATTERN(eql_trans, predicated_real(pattern(1), pattern(2), PRED_EQL));
 
-void eql_trans_scheme::compute(property const hyps[], property &res, std::string &) const
+void eql_trans_scheme::compute(property const [], property &, std::string &) const
 {
 }
 
@@ -732,6 +732,7 @@ proof_scheme *sub_flt_scheme::factory(predicated_real const &real, ast_real_vect
 {
   if (holders[0] == holders[1]) return NULL;
   if (is_constant(holders[0]) && is_constant(holders[1])) return NULL;
+  if (is_approx(holders[1], holders[0])) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[0], PRED_FLT));
   hyps.push_back(predicated_real(holders[1], PRED_FLT));
@@ -901,6 +902,7 @@ void bnd_of_nzr_rel_scheme::compute(property const hyps[], property &res, std::s
 proof_scheme *bnd_of_nzr_rel_scheme::factory(predicated_real const &real, ast_real_vect const &holders)
 {
   if (holders[0] == holders[1]) return NULL;
+  if (holders[0]->is_constant && holders[1]->is_constant) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[0], PRED_NZR));
   hyps.push_back(predicated_real(holders[1], holders[0], PRED_REL));
@@ -937,7 +939,7 @@ REGISTER_SCHEME_BEGIN(computation_rel_add);
     : proof_scheme(r, v, n) {}
 REGISTER_SCHEME_END_PREDICATE(computation_rel_add);
 
-void computation_rel_add_scheme::compute(property const hyps[], property &res, std::string &name) const
+void computation_rel_add_scheme::compute(property const hyps[], property &res, std::string &) const
 {
   res.bnd() = add_relative(hyps[0].bnd(), hyps[1].bnd(), hyps[2].bnd());
 }
@@ -1037,6 +1039,7 @@ void compose_rel_scheme::compute(property const hyps[], property &res, std::stri
 proof_scheme *compose_rel_scheme::factory(predicated_real const &real, ast_real_vect const &holders)
 {
   if (holders[0] == holders[2]) return NULL;
+  if (holders[1] == holders[2]) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[1], holders[0], PRED_REL));
   hyps.push_back(predicated_real(holders[0], holders[2], PRED_REL));
@@ -1045,6 +1048,7 @@ proof_scheme *compose_rel_scheme::factory(predicated_real const &real, ast_real_
 
 proof_scheme *compose_rel_scheme::factory2(predicated_real const &real, ast_real_vect const &holders)
 {
+  if (holders[0] == holders[2]) return NULL;
   if (holders[1] == holders[2]) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[2], holders[1], PRED_REL));
@@ -1098,6 +1102,7 @@ void error_of_rel_scheme::compute(property const hyps[], property &res, std::str
 proof_scheme *error_of_rel_scheme::factory(predicated_real const &real, ast_real_vect const &holders)
 {
   if (holders[0] == holders[1]) return NULL;
+  if (holders[0]->is_constant && holders[1]->is_constant) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[1], holders[0], PRED_REL));
   hyps.push_back(predicated_real(holders[0], PRED_BND));
@@ -1121,6 +1126,7 @@ void bnd_of_bnd_rel_scheme::compute(property const hyps[], property &res, std::s
 proof_scheme *bnd_of_bnd_rel_scheme::factory(predicated_real const &real, ast_real_vect const &holders)
 {
   if (holders[0] == holders[1]) return NULL;
+  if (holders[1]->is_constant) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[0], PRED_BND));
   hyps.push_back(predicated_real(holders[1], holders[0], PRED_REL));
@@ -1147,6 +1153,7 @@ proof_scheme *bnd_of_rel_bnd_scheme::factory(predicated_real const &real,
   ast_real_vect const &holders)
 {
   if (holders[0] == holders[1]) return NULL;
+  if (holders[0]->is_constant) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[1], PRED_BND));
   hyps.push_back(predicated_real(holders[1], holders[0], PRED_REL));
@@ -1252,6 +1259,7 @@ void nzr_of_nzr_rel_scheme::compute(property const hyps[], property &res, std::s
 
 proof_scheme *nzr_of_nzr_rel_scheme::factory(predicated_real const &real, ast_real_vect const &holders)
 {
+  if (holders[1]->is_constant) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[0], PRED_NZR));
   hyps.push_back(predicated_real(holders[1], holders[0], PRED_REL));
@@ -1264,12 +1272,13 @@ REGISTER_SCHEME_BEGIN(nzr_of_nzr_rel_rev);
     : proof_scheme(r, v, "nzr_of_nzr_rel_rev") {}
 REGISTER_SCHEME_END_PATTERN(nzr_of_nzr_rel_rev, predicated_real(pattern(-1), PRED_NZR));
 
-void nzr_of_nzr_rel_rev_scheme::compute(property const hyps[], property &res, std::string &) const
+void nzr_of_nzr_rel_rev_scheme::compute(property const [], property &, std::string &) const
 {
 }
 
 proof_scheme *nzr_of_nzr_rel_rev_scheme::factory(predicated_real const &real, ast_real_vect const &holders)
 {
+  if (holders[0]->is_constant) return NULL;
   preal_vect hyps;
   hyps.push_back(predicated_real(holders[1], PRED_NZR));
   hyps.push_back(predicated_real(holders[1], holders[0], PRED_REL));
