@@ -103,14 +103,15 @@ property node::maximal() const
 {
   property res;
   property const &current = get_result();
-  for(node_set::const_iterator i = succ.begin(), end = succ.end(); i != end; ++i)
+  for (node *n: succ)
   {
-    property p = (*i)->maximal_for(this);
+    property p = n->maximal_for(this);
     if (res.null()) res = p;
     else res.intersect(p);
+    assert(current.implies(res));
     if (!current.strict_implies(res)) break;
   }
-  return res.null() ? get_result() : res;
+  return res.null() ? current : res;
 }
 
 /**
@@ -175,14 +176,13 @@ modus_node::modus_node(theorem_node *n)
   assert(n);
   if (!proof_generator && parameter_constrained) return;
   node_set nodes;
-  for (property_vect::const_iterator i = n->hyp.begin(),
-       i_end = n->hyp.end(); i != i_end; ++i)
+  for (property const &p: n->hyp)
   {
-    node *m = find_proof(i->real);
-    if (!m || !m->get_result().implies(*i))
+    node *m = find_proof(p.real);
+    if (!m || !m->get_result().implies(p))
     {
       assert(!parameter_constrained);
-      m = create_theorem(0, NULL, *i, "$FALSE", NULL);
+      m = create_theorem(0, NULL, p, "$FALSE", NULL);
     }
     assert(m && dominates(m, this));
     if (nodes.insert(m).second)
@@ -204,12 +204,10 @@ property modus_node::maximal_for(node const *n) const
 {
   predicated_real r = n->get_result().real;
   property res;
-  for (property_vect::const_iterator i = target->hyp.begin(),
-       end = target->hyp.end(); i != end; ++i)
-  {
-    if (r != i->real) continue;
-    if (res.null()) res = *i;
-    else res.intersect(*i);
+  for (property const &p: target->hyp) {
+    if (r != p.real) continue;
+    if (res.null()) res = p;
+    else res.intersect(p);
   }
   assert(!res.null());
   return res;
@@ -376,11 +374,9 @@ graph_t::graph_t(graph_t *f, property_tree const &h)
     {
       ++i->second->nb_good;
     }
-    for (std::list<logic_node *>::const_iterator i = f->trees.begin(),
-         i_end = f->trees.end(); i != i_end; ++i)
-    {
-      ++(*i)->nb_good;
-      trees.push_back(*i);
+    for (logic_node *n: f->trees) {
+      ++n->nb_good;
+      trees.push_back(n);
     }
   }
   logic_node *n = new logic_node(h);
@@ -399,10 +395,8 @@ void graph_t::purge()
     i->second->remove_known();
   }
   known_reals.clear();
-  for (std::list<logic_node *>::const_iterator i = trees.begin(),
-       i_end = trees.end(); i != i_end; ++i)
-  {
-    (*i)->remove_known();
+  for (logic_node *n: trees) {
+    n->remove_known();
   }
   trees.clear();
 }
@@ -543,9 +537,7 @@ void graph_t::replace_known(node_vect const &v)
 {
   node_map old;
   old.swap(known_reals);
-  for (node_vect::const_iterator i = v.begin(), end = v.end(); i != end; ++i)
-  {
-    node *n = *i;
+  for (node *n: v) {
     ++n->nb_good;
     known_reals.insert(std::make_pair(n->get_result().real, n));
   }
@@ -560,9 +552,8 @@ void graph_t::replace_known(node_vect const &v)
 void graph_t::show_dangling() const
 {
   bool first = true;
-  for (node_set::const_iterator i = nodes.begin(), i_end = nodes.end(); i != i_end; ++i)
+  for (node *n: nodes)
   {
-    node *n = *i;
     if (n->type == MODUS && static_cast< modus_node * >(n)->target->name == "$FALSE")
     {
       if (first)
@@ -594,23 +585,20 @@ static void find_negative(preal_set &ps, property_tree const &t)
 void graph_t::show_negative() const
 {
   preal_set ps;
-  for (std::list<logic_node *>::const_iterator i = trees.begin(),
-       i_end = trees.end(); i != i_end; ++i)
-  {
-    find_negative(ps, (*i)->tree);
+  for (logic_node *n: trees) {
+    find_negative(ps, n->tree);
   }
   if (ps.empty()) {
     std::cerr << "Error: no contradiction was found.\n";
     return;
   }
   std::cerr << "Error: some properties were not satisfied:\n";
-  for (preal_set::const_iterator i = ps.begin(),
-       i_end = ps.end(); i != i_end; ++i)
+  for (predicated_real const &p: ps)
   {
-    std::cerr << "  " << dump_real(*i);
-    if (node *n = find_already_known(*i)) {
+    std::cerr << "  " << dump_real(p);
+    if (node *n = find_already_known(p)) {
       std::cerr << ", best: ";
-      if (i->pred_bnd()) std::cerr << n->get_result().bnd();
+      if (p.pred_bnd()) std::cerr << n->get_result().bnd();
       else std::cerr << n->get_result().cst();
     }
     std::cerr << '\n';
@@ -650,30 +638,24 @@ void enlarger(node *top)
       continue;
     }
     bn.first = true;
-    node_vect const &v = bn.second->get_subproofs();
-    for (node_vect::const_iterator i = v.begin(),
-         i_end = v.end(); i != i_end; ++i)
-    {
-      bns.push_back(std::make_pair(false, *i));
+    for (node *n: bn.second->get_subproofs()) {
+      bns.push_back(std::make_pair(false, n));
     }
   }
   // compute which nodes can be used as a replacement
   std::set<graph_t *> gs;
   std::multimap<graph_t *, graph_t *> ggs;
-  for (node_list::const_iterator i = pending.begin(),
-       i_end = pending.end(); i != i_end; ++i)
+  for (node *n: pending)
   {
-    graph_t *g = (*i)->graph;
+    graph_t *g = n->graph;
     if (!gs.insert(g).second) continue;
     // the nodes of k can be used by the nodes of g
     for (graph_t *k = g; k; k = k->father)
       ggs.insert(std::make_pair(k, g));
   }
   std::map<graph_t *, node_list> gnls;
-  for (node_list::const_iterator i = pending.begin(),
-       i_end = pending.end(); i != i_end; ++i)
+  for (node *n: pending)
   {
-    node *n = *i;
     typedef std::multimap<graph_t *, graph_t *>::const_iterator iter;
     std::pair<iter, iter> jj = ggs.equal_range(n->graph);
     // the nodes of *j can use node n
@@ -688,11 +670,8 @@ void enlarger(node *top)
     pending.pop_front();
     if (n->type == LOGIC || n->type == LOGICP) continue;
     n->enlarge(n->maximal());
-    node_vect const &v = n->get_subproofs();
-    for (node_vect::const_iterator i = v.begin(),
-         i_end = v.end(); i != i_end; ++i)
+    for (node *m: n->get_subproofs())
     {
-      node *m = *i;
       property p = n->maximal_for(m);
       if (!m->get_result().strict_implies(p)) continue;
       node_list const &ns = gnls[m->graph];
@@ -701,6 +680,8 @@ void enlarger(node *top)
       {
         assert (j != j_end);
         node *k = *j;
+        // TODO: replace n entirely by k in that case, as it implies that k dominates n
+        if (n->type == UNION && k->graph->father != n->graph) continue;
         if (k->type == LOGIC) continue;
         if (!k->get_result().implies(p)) continue;
         ++m->nb_good;
@@ -710,9 +691,7 @@ void enlarger(node *top)
       }
     }
   }
-  for (node_list::const_iterator i = replaced.begin(),
-       i_end = replaced.end(); i != i_end; ++i)
-  {
-    (*i)->remove_known();
+  for (node *n: replaced) {
+    n->remove_known();
   }
 }
